A suite of routines for visualizing SPH simulations.

- camera : OpenGL-alike matrix transformations from simulation to clipping and device coordinates
- svr : survey volume remapping
- painter : SPH resampling windows.
- color : efficient colormaps for large images
